# coding: utf-8

"""
    Picteus

    The Picteus API

    The version of the OpenAPI document: 0.13.0
    Contact: edouard@koppasoft.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from picteus_ws_client.models.search_features_result import SearchFeaturesResult

class TestSearchFeaturesResult(unittest.TestCase):
    """SearchFeaturesResult unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> SearchFeaturesResult:
        """Test SearchFeaturesResult
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `SearchFeaturesResult`
        """
        model = SearchFeaturesResult()
        if include_optional:
            return SearchFeaturesResult(
                items = [
                    picteus_ws_client.models.extension_image_features_attribute.ExtensionImageFeaturesAttribute(
                        id = 'fb6af249-1061-48a0-9e47-026d7428d709', 
                        attribute = [
                            picteus_ws_client.models.extension_image_feature.ExtensionImageFeature(
                                type = null, 
                                format = null, 
                                name = 'field', 
                                value = Three women in a flower arrangement, 
                                id = 'extension-id', )
                            ], )
                    ],
                total_count = 0
            )
        else:
            return SearchFeaturesResult(
                items = [
                    picteus_ws_client.models.extension_image_features_attribute.ExtensionImageFeaturesAttribute(
                        id = 'fb6af249-1061-48a0-9e47-026d7428d709', 
                        attribute = [
                            picteus_ws_client.models.extension_image_feature.ExtensionImageFeature(
                                type = null, 
                                format = null, 
                                name = 'field', 
                                value = Three women in a flower arrangement, 
                                id = 'extension-id', )
                            ], )
                    ],
                total_count = 0,
        )
        """

    def testSearchFeaturesResult(self):
        """Test SearchFeaturesResult"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
