# coding: utf-8

"""
    Picteus

    The Picteus API

    The version of the OpenAPI document: 0.13.0
    Contact: edouard@koppasoft.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import json
from enum import Enum
from typing_extensions import Self


class ImageFeatureNullValue(str, Enum):
    """
    The value to pass to the image search web services to designate a 'non-null' feature value
    """

    """
    allowed enum values
    """
    EMPTY = ''

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of ImageFeatureNullValue from a JSON string"""
        return cls(json.loads(json_str))


