# coding: utf-8

"""
    Picteus

    The Picteus API

    The version of the OpenAPI document: 0.13.0
    Contact: edouard@koppasoft.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from picteus_ws_client.models.extensions_configuration import ExtensionsConfiguration

class TestExtensionsConfiguration(unittest.TestCase):
    """ExtensionsConfiguration unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ExtensionsConfiguration:
        """Test ExtensionsConfiguration
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ExtensionsConfiguration`
        """
        model = ExtensionsConfiguration()
        if include_optional:
            return ExtensionsConfiguration(
                capabilities = [
                    picteus_ws_client.models.configuration_capability.ConfigurationCapability(
                        capability = null, 
                        extension_ids = [
                            '26bUUGjjNSwg0_bs9ZayIMrK'
                            ], )
                    ],
                commands = [
                    picteus_ws_client.models.configuration_extension_command.ConfigurationExtensionCommand(
                        extension_id = 'extension-id', 
                        command = null, )
                    ]
            )
        else:
            return ExtensionsConfiguration(
                capabilities = [
                    picteus_ws_client.models.configuration_capability.ConfigurationCapability(
                        capability = null, 
                        extension_ids = [
                            '26bUUGjjNSwg0_bs9ZayIMrK'
                            ], )
                    ],
                commands = [
                    picteus_ws_client.models.configuration_extension_command.ConfigurationExtensionCommand(
                        extension_id = 'extension-id', 
                        command = null, )
                    ],
        )
        """

    def testExtensionsConfiguration(self):
        """Test ExtensionsConfiguration"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
